==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AbsoluteVolumeOscillatorIndicator, _super);
    function AbsoluteVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AbsoluteVolumeOscillatorIndicator.prototype.get_up = function () {
        return new AbsoluteVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.get_u2 = function () {
        return AbsoluteVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.vb));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.ux = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.va));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.va, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.uu = function () {
        return this.longPeriod;
    };
    AbsoluteVolumeOscillatorIndicator.$t = markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.vb = StrategyBasedIndicator.u9(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.va = StrategyBasedIndicator.u5(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { AbsoluteVolumeOscillatorIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AbsoluteVolumeOscillatorIndicator, _super);
    function AbsoluteVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AbsoluteVolumeOscillatorIndicator.prototype.get_yy = function () {
        return new AbsoluteVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.get_zb = function () {
        return AbsoluteVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.zk));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.y6 = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(AbsoluteVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.zj));
        },
        set: function (a) {
            this.h(AbsoluteVolumeOscillatorIndicator.zj, a);
        },
        enumerable: false,
        configurable: true
    });
    AbsoluteVolumeOscillatorIndicator.prototype.y3 = function () {
        return this.longPeriod;
    };
    AbsoluteVolumeOscillatorIndicator.$t = markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.zk = StrategyBasedIndicator.zi(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.zj = StrategyBasedIndicator.ze(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { AbsoluteVolumeOscillatorIndicator };
